module.exports = defineTest({
	description: 'debugger statements are preserved (#664)'
});
